/*==========================================
	Building up a panel for individuals
===========================================*/


use "..\data\lits2006", clear

keep 	country countryname id q601* q602?_* weight_* q602* q603? q604* q6054* q602b5* q602b4* ///
		genderB ageB q501 q502 tablec relationheadB q103_* q605*  tabled 
		 
// create all personal variables  

gen y_birth =  2006 - ageB
forvalues y	= 1989/2006{
gen age_`y' = `y'-y_birth
}


gen fem = genderB==0 
label var fem  "Female=1"

*marriage  
gen mstat2006 = 0 
replace mstat2006 = 1 if relationheadB==2 | relationheadB == 9 | relationheadB==10 
forvalues k = 2/12{ 
replace mstat2006 = 1 if relationheadB==1 & q103_`k' == 2
replace mstat2006 = 1 if relationheadB==1 & q103_`k' == 3 
replace mstat2006 = 1 if q601b_18==1
}

forvalues i = 1/17{
local y		= 2006 - `i'
local y2	= 2006 - `i' +1
local q 	= 19 -`i'


gen mstat`y' = mstat`y2'
replace mstat`y' = 0 if q601b_`q'==1
replace mstat`y' = 1 if q601d_`q'==1
}

* Education  
label define educat 1 "Lower" 2 "Medium" 3 "High"
gen educ2006 = q501
forvalues y = 1989/2005{
gen educ`y' = educ2006
replace educ`y' = educ2006-1 if q502>`y' & q501!=1 
}	
forvalues y = 1989/2006{
recode educ`y' (1/2=1)(3/4=2)(5/6=3)
replace educ`y'= . if q501==.
label val educ`y' educat
}



* Urban or rural variables
gen urban2006= tablec==1 | tablec==3
forvalues i = 1/17{
local y	 	= 2006 -`i'
local y1 	= 2006 -`i'+1
local r		= 19 - `i'
gen urban`y' = urban`y1'
replace urban`y' = 0 if  q6057_`r'==1 // moved from rural to urban in 2006
replace urban`y' = 1 if  q6058_`r'==1 // moved from urban to rural in 2006
}	


  /////////////////////////////////
 //		Job related vars		//
/////////////////////////////////

local i =0
forvalues y = 1989/2006{
local ++i

gen job_bel`y' = q6052_`i' ==1
label var job_bel`y' "Job below qualifications"

gen wage_arr`y'= q6053_`i' ==1
label var wage_arr`y' "Accepted wage arrears"

gen cut_cons`y'= q60510_`i' ==1
label var cut_cons`y' "Cut down on basic food cons"

gen better_job`y'= q60511_`i' ==1
label var better_job`y' "Found a better job"

gen mil`y'		=	q601a_`i'==1
label var mil`y' "Military service"

}



*Other incomes
label def sources	 1 "Unemployment benef" 2 "Relatives" 3 "Sold assets" 0 "None"
local i =0
forvalues y = 1989/2006 {
local ++i
gen other_inc`y' = 0
replace other_inc`y' =1 if q6051_`i'==1			// Unemployment benefits
replace other_inc`y' =2 if q6055_`i'==1			// Financial assistance by relatives	
replace other_inc`y' =3 if q6059_`i'==1     	// Sold hh assets
label val other_inc`y' sources
}
//



// Create a description of the different jobs
///////////////////////////////////////////////////



foreach l in `c(alpha)'{
if "`l'"> "n" continue

gen own`l' = .
forvalues i = 1/4{
replace own`l' = `i' if q602b3`l'`i'==1
 }
label val own`l' owners 

 
recode q602b2`l' (1/2=1)(3/5=2)(6=3)(7/11 =4)(12/17=5), gen(industry`l')
label val industry`l' industrial

gen hskill`l' = q602b1`l'<4 & q602b1`l'!=.
 
gen abroad`l' = 1 if q602b4`l'==1
 
 }
 
 
 foreach l in `c(alpha)' {
 if "`l'"> "n" continue
gen yearstart`l'=0
gen yearend`l'=0

local i =1
forvalues y = 1989/2006{
replace yearstart`l' = `y' if q602`l'_`i' ==1 & yearstart`l'==0
replace yearend`l' = `y'-1 if q602`l'_`i' ==0 & yearstart`l'!=0 & yearend`l' ==0
local ++i
}
}
//

 foreach l in `c(alpha)' {
 if "`l'"> "n" continue
replace yearend`l' = 2006 if q602`l'_18 ==1 
}
//
 foreach l in `c(alpha)' {
 if "`l'"> "n" continue
tab yearend`l' if yearstart`l'==0
}

 foreach l in `c(alpha)' {
 if "`l'"> "n" continue
tab yearend`l' if yearstart`l'!=0
}


// Main work => Best occupation

 foreach l in `c(alpha)' {
 if "`l'"> "n" continue
	forvalues i =	1/18{
		gen occupa`l'_`i' = .
		replace occupa`l'_`i' = q602b1`l' if q602`l'_`i'==1
		}
}

local i =0
forvalues y = 1989/2006{
	local ++i
	gen occup_`y'=.
	gen str1 workv`y'=""
	
	foreach l in `c(alpha)' {
		if "`l'"> "n" continue
		replace workv`y'= "`l'" if q602`l'_`i'==1 & occupa`l'_`i'!=. & occupa`l'_`i'<occup_`y'
		replace occup_`y' = occupa`l'_`i' if q602`l'_`i'==1 & occupa`l'_`i'!=. & occupa`l'_`i'<occup_`y'
		replace workv`y' =	"" if age_`y' <15
	}
	label var workv`y' "Main work"
	drop occup_`y'
}

foreach l in `letters'{
forvalues i =	1/18{
drop occupa`l'_`i'
}
}



local t=0
forvalues y = 1989/2006{
local ++t
gen tot_wrks`y'	=	0
 foreach l in `c(alpha)' {
	if "`l'"> "n" continue
	quiet replace tot_wrks`y' = tot_wrks`y' + q602`l'_`t' if q602`l'_`t' != .
}

}


 label def owners	 1 "Public" 2 "Private" 3 "Foreign" 4 "Doesnt know"
label def industrial 1 "Agriculture" 2 "Industry" 3 "Construction" 4 "Services" 5 "Non-mkt services"

forvalues y = 1989/2006{
gen industryv`y'	=.
gen existedv`y'		=.
gen sectorv`y'		=.
gen occupav`y'		=.
gen abroadv`y'	=.
gen leavingv`y'	=.

foreach l in `c(alpha)' {
	if "`l'"> "n" continue

	replace industryv`y' 	= industry`l' 	if workv`y'=="`l'"
	replace existedv`y'		= q602b5`l'		if workv`y'=="`l'"
	replace sectorv`y'		= own`l'		if workv`y'=="`l'"
	replace occupav`y'		= q602b1`l'		if workv`y'=="`l'"
	replace abroadv`y'		= q602b4`l'		if workv`y'=="`l'"
	replace leavingv`y'		= q603`l'		if workv`y'=="`l'"

	label val industryv`y' 	industrial
	label val sectorv`y' 	owners
}
 
}
 
replace existedv1989	= 1		if workv1989!="" & existedv1989==.
 
forvalues y = 1990/2006{
local y1= `y' - 1
replace existedv`y' = existedv`y1' if workv`y'==workv`y1' & existedv`y'==.
}
 

gen start_year = .
forvalues y= 1989/2006{
replace start_year = `y' if workv`y' !="" & start_year==.
}
 

gen retire_lits =.
local i =0
forvalues y = 1989/2006 {
local ++i
replace retire_lits = `y' if q601e_`i'==1
}
 
 
gen retire_own=0
forvalues y = 1989/2006 {
replace retire_own = `y' if (workv`y' != "") 
} 
replace retire_own = . if retire_own==0				
replace retire_own = . if retire_own==2006		

 
gen ever_abroad=0
forvalues y = 1989/2005{
replace ever_abroad =1 if abroadv`y' ==1
}
**

** RESHAPING THE DATABASE
local hhvars 	"educ  mstat mil"
local lmsvars	"other_inc   workv industryv  sectorv urban abroadv  occupav"
local others	"job_bel wage_arr cut_cons better_job  existedv leavingv "
local timecons	" y_birth retire_lits fem  q502 retire_own "
local timecons2	"tabled countryname id year weight_0 weight_1 weight_2 start_year"	


reshape long `hhvars' `lmsvars'	`others', i(id) j(year)
keep `hhvars' `lmsvars' `others' `timecons' `timecons2' id year

global name0	"countryname"
quiet do "country codes"
drop if c_code=="TUR" | c_code=="MNG"

merge m:1 year c_code using "..\data\datawb", keepusing(gdpconstant2005us gdp_pc unemp_wb)
drop if _merge==2
drop  _merge
 
* Demographic variables 
gen age = year - y_birth
 
capture drop if educ==0
tab educ, gen(deduc)
label var deduc1 "lower education"
label var deduc2 "medium education"
label var deduc3 "higher education"


* Technical variables
bys c_code year: gen fobs = _n==1
xtset id year

 



*Labor market status
*------------------------------------------

local i =0
foreach l in `c(alpha)'{
if "`l'">"n" continue
local ++i
replace workv = "`i'" if workv=="`l'"
}
destring workv, replace
replace workv = . if abroadv==1

gen non_emp = workv==.
egen n_non = total(non_emp), by(id)

gen las_work = .
forvalues y = 1989/2006{
replace las_work =`y' if year==`y' & workv!=.
}
egen last_work = max(las_work), by(id)

 


gen unemp_a = workv==.
replace unemp_a = 3 if n_non==18 & retire_lits==.
replace unemp_a = 4 if year<q502 & age<26 & year<start_year	& age>15
replace unemp_a = 5 if workv==. & (age<15 | age>64)
replace unemp_a = 2 if workv==. & year >=retire_lits & year>=last_work & last_work!=.
replace unemp_a = 2 if l.unemp_a==2 & workv==.
replace unemp_a = 3 if workv==. & mil==1
replace unemp_a	= .	if abroadv ==1

label define non_emp 	0 "Employed" 1 "Unemployed" 2 "Retired" 3 "Inactive" ///
						4 "School" 5 "Not in Labor force" 

label val unemp_a   non_emp

capture drop n_non non_emp las_work last_work

gen auxa			= unemp_a == 1 | unemp_a ==0
gen aux2a			= unemp_a	== 1
egen lab_forc	= total(auxa) , by(country year)
egen unemployed	= total(aux2a), by(country year)
 

gen u_rate = unemployed/lab_forc
drop aux* 
 
 
gen pubv		= 	sectorv == 1 	
replace pubv 	= . if workv ==. 
gen priv		= 	sectorv != 1 	
replace priv 	= . if workv ==. 

gen servv		= industryv ==4	
replace servv	= . if workv ==. 
gen indv		= industryv !=4	
replace indv	= . if workv ==. 

replace existedv 	= . if workv ==.
 
label define types    0 "Public" 1 "DeNovo" 2 "Privatized" 
gen firmtypev		= .
replace firmtypev	= 1 if	pubv==0	& existedv ==0					//  de novo	(ownership!=public)
replace firmtypev	= 2 if	pubv==0	& existedv ==1					//	privatized (ownership!=public)
replace firmtypev	= 0 if	pubv==1										//  Public
label val firmtypev types

 
gen changev	=	workv!=l.workv & year>1989					// Reallocation
gen new_w_v	=	workv!=l.workv & workv!=. & year>1989		// any flows to E
gen end_w_v	=	workv!=l.workv & l.workv!=. & year>1989	// any flows out of E
gen employedv	=	workv!=.										// ALL E
  

 
gen pub		=	pubv==1
gen serv	=	servv==1
gen de_novo = 	firmtypev==1
gen inds 	=	industryv ==2
gen p_den	= 	de_novo
replace p_den = l.p_den if workv==.

gen p_pri	= de_novo ==0 & pubv==0 & workv!=.
replace p_pri = l.p_pri if workv==.

gen den 	=	de_novo
gen pri		=	de_novo ==0 & pubv==0 & workv!=.

gen p_industry = l.industryv if workv==.
 

* Job flows
*-------------------------------------
 
gen t_unemp_a 	= unemp_a == 1 	& l.unemp_a ==0	& year>1989		
gen f_unemp_a 	= unemp_a == 0 	& l.unemp_a ==1	& year>1989
gen t_unemp_a2	= unemp_a == 1 	& l.unemp_a !=0	& l.unemp_a!=1 	
gen f_school_a	= unemp_a == 0 	& l.unemp_a ==4
gen t_retire_a	= unemp_a == 2 	& l.unemp_a==0 	& year>1989
gen t_retire2_a	= unemp_a == 2 	& l.unemp_a !=2	& year>1989
gen t_inact_a	=(unemp_a ==3 | unemp_a ==5) & l.unemp_a==0 &  year>1989


local workers	"workv!=l.workv & workv!=. & l.workv!=. & year>1989"
gen ab0		 =	`workers' & l.pubv == 1 & pubv == 0 & l.servv==servv
gen ch0		 =	`workers' & l.servv == 0 & servv==1 & l.pubv==pubv
gen both0	 =	`workers' & l.servv != servv  & l.pubv!=pubv 
gen abch0	 =	`workers' & l.servv == 0 & servv==1 & l.pubv == 1 & pubv == 0
gen none0	 =	`workers' & l.servv == servv  & l.pubv==pubv 
gen anti0	 =	`workers' & l.servv == servv  & l.pubv== 0 & pubv == 1
replace anti0=	1 if `workers' & l.servv ==1 & servv== 0  & l.pubv==pubv

capture gen ab_np = ab0==1 & firmtypev!=2
capture gen ab_p =  ab0==1 & firmtypev==2


label var 	ab0 	"AB"
label var 	ab_np	"AB (de_novo)"
label var 	ab_p	"AB (privatized)"
label var 	ch0 	"CH"
label var 	abch0 	"ABCH"
label var 	none0 	"SAME"
label var 	anti0 	"Opposite"




save "..\data\data_user", replace
 
exit



