*===============================================*
*		The structure of completed flows		*
*===============================================*


use "..\data\data_user", clear

egen never_wrk	=min(workv==.), by(id)

** Recover starting and final status
*----------------------------------------------
egen st_sec		= max((year==1989)*sectorv), by(id)
egen end_sec	= max((year==2006)*sectorv), by(id)

egen st_e89		= max((year==1989)*existedv), by(id)
egen end_e89	= max((year==2006)*existedv), by(id)

egen st_lms		=max((year==1989)*unemp_a), by(id)
egen end_lms	=max((year==2006)*unemp_a), by(id)

egen st_ind		=max((year==1989)*industryv), by(id)
egen end_ind	=max((year==2006)*industryv), by(id)

egen st_wrk		=max((year==1989)*workv), by(id)
egen end_wrk	=max((year==2006)*workv), by(id)



capture drop l_pri
gen l_pri = 1-pubv if unemp_a==0
replace l_pri = l.l_pri if l_pri==. & l.l_pri!=.

capture drop l_serv
gen l_serv = indus==4 if unemp_a==0
replace l_serv = l.l_serv if l_serv==. & l.l_serv!=.
 

** Flow measures 
*----------------------------

gen same_ult = st_lms ==0 & end_lms==0 & st_sec == end_sec & st_ind ==end_ind & st_wrk!=end_wrk & (st_ind!=1 | st_ind!=3 | st_ind!=5)

gen ab_ult 	 = st_lms ==0 & end_lms==0 & st_sec == 1 & end_sec!=1 & st_ind ==end_ind & (st_ind!=1 | st_ind!=3 | st_ind!=5)

gen ch_ult 	 = st_lms ==0 & end_lms==0 & st_sec == end_sec & st_ind ==2 & end_ind ==4 & (st_ind!=1 | st_ind!=3 | st_ind!=5)

gen abch_ult= st_lms ==0 & end_lms==0 & st_sec == 1 & end_sec>1 & st_ind ==2 & end_ind ==4 & (st_ind!=1 | st_ind!=3 | st_ind!=5)

gen abp_ult2		= (ab_ult==1  |abch_ult==1) & st_e89==1 & end_e89==1 

gen abnp_ult2		= (ab_ult==1 | abch_ult==1)   & st_e89==1 & end_e89==0  

gen none_ult= st_lms ==0 & end_lms==0 & end_sec == 1 & st_sec>1 & (st_ind!=1 | st_ind!=3 | st_ind!=5)
replace none_ult = st_lms ==0 & end_lms==0 & st_ind>3 & end_ind ==2 & (st_ind!=1 | st_ind!=3 | st_ind!=5)

gen entry_ult  =  (st_lms ==4 | (st_lms ==5 & age<25) ) & end_lms==0 & (st_ind!=1 | st_ind!=3 | st_ind!=5)

gen exit_ult  =  (end_lms ==2 | (end_lms ==5 & age>65) ) & st_lms==0	 & (st_ind!=1 | st_ind!=3 | st_ind!=5)
 
gen incomp_ult =  st_lms ==0 & exit_ult==0 & end_lms>0  & (st_ind!=1 | st_ind!=3 | st_ind!=5) & l_serv!=1 & l_pri!=1

 

** Figure 2
*---------------------------

 keep if year ==1990 & never_wrk==0
collapse (mean)	same_ult ab_ult ch_ult abch_ult none_ult entry_ult exit_ult ///
				  abp_ult2 abnp_ult2 incomp_ult  (first) c_code  ///
				  if (st_ind!=1 | st_ind!=3 | st_ind!=5) [iw=weight_1], by(country)
				 
gen sumer =same_ult+ab_ult+ch_ult+abch_ult+none_ult+entry_ult+exit_ult+incomp_ult

set scheme s1mono

* Upper panel 	
graph hbar  (mean) ab_ult ch_ult  abch_ult  same_ult none_ult incomp_ult entry_ult exit_ult   , /// 
	over(c_code, sort(sumer)  descending gap(*.5) label(labsize(vsmall))) stack ///
	legend(size(vsmall) order(1 "OWNERSHIP" 2 "SECTORAL" 3 "OWN. & SECT." 4 "SAME"   ///
	5 "OPPOSITE" 6 "Non-employment" 7 "ENTRY" 8 "EXIT" 	)) ytitle( "Fraction of respondents" , size(small)) ///
	 ylabel(,labsize(small)) legend(row(2) region(lcolor(none))) ylab(, nogrid)  xsize(6) name(ult, replace) ///
		bar(1, fcolor(dknavy) lcolor(white) fintensity(100)) ///
		bar(2, fcolor(dknavy) lcolor(white) fintensity(60)) ///
		bar(3, fcolor(dknavy) lcolor(white) fintensity(40)) ///
		bar(4, fcolor(black) lcolor(white) fintensity(50)) ///
		bar(5, fcolor(black) lcolor(white) fintensity(30)) ///
		bar(6, fcolor(black) lcolor(white) fintensity(15)) ///
		bar(7, fcolor(maroon) lcolor(white) fintensity(40)) ///
		bar(8, fcolor(maroon) lcolor(white) fintensity(90))	  
		
		
* Lower panel		
graph hbar  (mean) abp_ult2 abnp_ult2 , /// 
	over(c_code, sort(sumer)  descending gap(*.5) label(labsize(vsmall))) stack ///
	legend(size(vsmall)  order(1 "PRIVATIZATION" 2 "DE NOVO") ) ///
	ytitle( "Fraction of respondents" , size(small)) ylab(, nogrid) ///
	 ylabel(,labsize(small)) legend(col(2) region(lcolor(none))) scheme(s1mono) ///
	bar(1, fcolor(dknavy) lcolor(white) fintensity(95)) ///
	bar(2, fcolor(dknavy) lcolor(white) fintensity(70)) 	
