/*============================================
		The size of flows
==============================================*/
 
use "..\data\data_user" , clear
 
** Data preparation 
 
gen emp = unemp_a==0
gen unemp = unemp_a==1

* Countries and years from the literature
gen 	keeper= c_code=="EST" & year>1991 & year<2002
replace keeper=1 if c_code=="RUS" & year>1989 & year<2001
replace keeper=1 if c_code=="RUS" & year==2004
replace keeper=1 if c_code=="UKR" & year>1991 & year<2001
replace keeper=1 if c_code=="BGR" & year>1993 & year<1998
replace keeper=1 if c_code=="POL" & year>1993 & year<2001
replace keeper=1 if c_code=="ROM" & year>1994 & year<1998
replace keeper=1 if c_code=="SVN" & year>1990 & year<1997
replace keeper=1 if c_code=="SVK" & year >1993 & year<1998
replace keeper=1 if c_code=="SVK" & year >1999 & year<2005
replace keeper=1 if c_code=="CZE" & year >1991 & year<1997
replace keeper=1 if c_code=="HUN" & year >1992 & year<1997



global vars "ab0 ch0 abch0 none0 anti0 t_unemp_a f_school_a t_retire_a"
collapse (sum) $vars  emp  unemp (first) c_code gdp_pc unemp_wb keeper [iw=weight_1]   , by(country year)

gen unemp_rate = unemp/(unemp+emp)  
xtset  country year
foreach x in $vars{
replace `x' = `x' /l.emp  
}

gen ch_gdp = gdp_pc/l.gdp_pc -1
tab c_code, gen(dcc)
 
** TABLE C.1 and C.2
 
global opts  drop(dcc*) excel dec(3) label
cd ..\logs
foreach y in $vars{

if "`y'" == "ab0" local what "replace"
if "`y'" != "ab0" local what " "

xi: quiet reg `y' ib1990.year dcc*  if year >1989  , nocons
estimates store `y'
*outreg2 using "mod_12_2016" , $opts `what' title("Time effects")  

quiet margins year  , post
estimates store `y'_1

xi: quiet reg `y' ib1990.year dcc*   if year >1989 , nocons
estimates store `y'_2
*outreg2  using "mod_12_2016a" , $opts  `what'   title("Base specifs") 

xi: quiet reg `y' ib1990.year dcc* l.`y' ch_gdp unemp_rate  if year >1989 , nocons  
estimates store `y'_3
  test l.`y' ch_gdp unemp_rate 
*outreg2  using "mod_12_2016b" , $opts  `what' adds(F-test, r(F),pval,r(p))  title("Add. Controls") 


xi: quiet reg `y' i.year dcc*  if year >1989 & keeper==1  , nocons
estimates store `y'_4
*outreg2 using "mod_12_2016c" , $opts  `what' title("Also in literature")


}
cd ..\do_files

 

** Figure 3
*------------------------------
 
* Sectoral flows
coefplot ab0_1  f_school_a_1 t_retire_a_1  , keep(*year*) vertical ///
		legend(order(2 "Ownership" 4 "Entry" 6 "Exit"  ) c(3)) ///
		legend(region(lcolor(none))) scheme(s1mono) ylabel(,angle(horizontal)) ///
		ytitle("Predicted means and 90% CI") xlabel(1 "1991" 5 "1995" 10 "2000" 16"2006") ///
		 yline(0) xtitle("Year")  ci(90) name(gr1_12_2016, replace)
 
* Industry flows		 
coefplot ch0_1  f_school_a_1 t_retire_a_1  , keep(*year*) vertical ///
		legend(order(2 "Sectoral" 4 "Entry" 6 "Exit" ) c(3)) ///
		legend(region(lcolor(none))) scheme(s1mono) ylabel(,angle(horizontal)) ///
		ytitle("Predicted means and 90% CI") xlabel(1 "1991" 5 "1995" 10 "2000" 16"2006") ///
		yline(0) xtitle("Year") ci(90)	name(gr2_12_2016, replace)	 

 
		 
exit
