/*========================================
	Survival data: Between models
=========================================*/
 
run "upload/surv_data"
run surv_data_prep_2 
 
preserve
keep if year ==1989
 
     
drop if age>65
drop if lazy
drop if at_risk==0
drop if some_indus==0
drop if time_event<0
	
count	
	
gen all_pri = pri + den

stset time_event ,f(failure) id(id) 
	unique id if at_risk & age89<=65 & lazy!=1 & some_indus & (init_indus==2 |init_indus==4) & early_ret==0
 

global xs 		"i.fem  ib1.max_edu i.mstat i.urban"
global s_1989	"share_pri share_man"
global s_exit 	"share_pri_exit share_den_exit share_man_exit"
global firm  	"ib4.init_indus i.init_pub"

 
 
foreach var in share_pri share_man share_pri_exit share_den_exit  ///
			share_man_exit risk_sep_sect tot_entry_all tot_entry_own  {
 
 replace `var' = `var' * 100

}
 
 
* TABLE 1

/*Everybody*/
 
global opts "dec(3) excel adds(L10,$L10, , L1 , $Ll, pvalue, $pvalue)"
global ifs  (init_indus==2 | init_indus==4 )  & risk_sep_sect !=. 
 count if  risk_sep_sect !=. 

streg $xs $firm    i.cn if $ifs , d(ggamma)
 local L10 = `e(ll_0)'
local L1 = `e(ll)'
est store all1
margins , dydx($xs $firm   ) post
*outreg2 using "surv_2017_mfx",  replace   dec(3) excel addstat(L10,`L10' , L1,`L1')  
 
streg $xs $firm  risk_sep_sect  i.cn if $ifs , d(ggamma)
 local L10 = `e(ll_0)'
local L1 = `e(ll)'
est store all2
lrtest all1 all2
local pvalue= `r(p)'
margins , dydx($xs $firm  risk_sep_sect  ) post
*outreg2 using "surv_2017_mfx",   dec(3) excel addstat(L10,`L10' , L1,`L1' , pvalue,`pvalue')

streg $xs $firm  risk_sep_sect  tot_entry_sect i.cn if $ifs , d(ggamma)
local L10 = `e(ll_0)'
local L1 = `e(ll)'
est store all3
lrtest all1 all3
local pvalue= `r(p)'
margins , dydx($xs $firm  risk_sep_sect   tot_entry_sect  ) post
*outreg2 using "surv_2017_mfx",   dec(3) excel addstat(L10,`L10' , L1,`L1' , pvalue,`pvalue')

 streg $xs $firm  risk_sep_sect  tot_entry_sect  $s_exit $s_1989 i.country if $ifs ,d(ggamma) 
local L10 = `e(ll_0)'
local L1 = `e(ll)'
est store all
lrtest all1 all
local pvalue= `r(p)'
margins , dydx($xs $firm  risk_sep_sect   tot_entry_sect $s_exit $s_1989 )  post
*outreg2 using "surv_2017_mfx",   dec(3) excel addstat(L10,`L10' , L1,`L1' , pvalue,`pvalue')

 
/* Under 45 in 1989 */	

global ifs (init_indus==2 | init_indus==4 ) & age89<=45 & risk_sep_sect !=. 

streg $xs $firm risk_sep_sect tot_entry_sect $s_exit $s_1989 i.country if $ifs & e(sample) ,d(ggamma) 
local L10 = `e(ll_0)'
local L1 = `e(ll)'
est store under2
capture local pvalue= `r(p)'
margins , dydx($xs $firm  risk_sep_sect    tot_entry_sect $s_exit $s_1989 ) post
*outreg2 using "surv_2017_mfx_robust",   dec(3) excel addstat(L10,`L10' , L1,`L1', pvalue,`pvalue')

/* Over 45 in 1989 */

global ifs (init_indus==2 | init_indus==4 ) & age89>45 & risk_sep_sect !=. 

streg $xs $firm  risk_sep_sect tot_entry_sect $s_exit $s_1989 i.country if $ifs ,d(ggamma) 
local L10 = `e(ll_0)'
local L1 = `e(ll)'
est store over2
 capture local pvalue= `r(p)'
margins , dydx($xs $firm  risk_sep_sect    tot_entry_sect $s_exit $s_1989 ) post
*outreg2 using "surv_2017_mfx_robust",   dec(3) excel addstat(L10,`L10' , L1,`L1' , pvalue,`pvalue')

/* Placebo */
streg $xs $firm  risk_sep_sect tot_entry_all tot_entry_own $s_exit $s_1989 i.cn if $ifs ,d(ggamma) 
local L10 = `e(ll_0)'
local L1 = `e(ll)'
est store over2
 capture local pvalue= `r(p)'
margins , dydx($xs $firm  risk_sep_sect   tot_entry_all tot_entry_own $s_exit $s_1989 ) post
*outreg2 using "surv_2017_mfx_robust",   dec(3) excel addstat(L10,`L10' , L1,`L1' , pvalue,`pvalue')


* TABLE D.2
* Descriptives from the most important regressions only, one for each group.

foreach var in all under2 over2{
est restore `var'
 estat sum
matrix aux_`var' =  r(stats)
matrix b_`var' =  aux_`var'[1..16,1..2]
}
 

* Figure D.2 - Left panel

encode c_code, gen(cn)
 	
global ifs  (init_indus==2 | init_indus==4 )  & risk_sep_sect !=. 
streg $xs $firm    i.cn if $ifs , d(ggamma)
estimates store all1 
 
sts graph if e(sample), ci   xtitle("Analysis time " "(Initial date: age =45 years old)")	///
			scheme(s1mono)	legend(off) name(k_m1, replace) ytitle("Survival") ///
			title("Kaplan-Meier survival estimate")  ylab(0(.25)1 , angle(horizontal))


stcurve	 , 	survival    xtitle("Analysis time " "(Initial date: age =45 years old)") ///
			name(fitted1, replace) scheme(s1mono) title("Estimated survival function") ///
			ylab(0(.25)1 , angle(horizontal) grid)

graph combine k_m1 fitted1 , title("All individuals")	scheme(s1mono) ///
				name(combined, replace)  

 
* Figure 6

global ifs  (init_indus==2 | init_indus==4 )  & risk_sep_sect !=. 
streg $xs $firm    i.cn if $ifs , d(ggamma)
margins cn, post
est store cns
est table cns

matrix l2 = r(coef)

 