/* Survival Data for individuals*/


use "..\data\data_user", clear

* --> Dependent variable

egen retirees = max(t_retire2_a),by(id)
egen age_ret2 = max(age*(t_retire2_a==1& retirees==1) + age*(retirees==0) ), by(id)

gen failure = retirees==1

capture drop time_*
gen time_event = age_ret -44
gen time_start = age -45
gen time_end = age -44

* --->  Independent variables
egen some_indus = max(indus==2 | indus==3 | indus==4), by(id)
encode c_code, gen(cn)
egen age89 = min(age), by(id)

egen year_ret = max(year*(t_retire2_a==1)), by(id)

replace industryv = . if workv ==.
replace sectorv = . if workv==.

gen old_sector = sectorv
replace old_sector = l.old_sector if old_sector==. 

gen old_ind = industryv
replace old_ind = l.old_ind if old_ind==. 

 
gen emp = unemp_a==0

egen tot_empl	= total(emp), by(country year)
egen empl_indus = total(emp) , by(indus country year)

egen empl_man_all = total(emp*(indus==2 )) , by( country year)
egen empl_serv_all = total(emp*(indus==4)) , by( country year)
egen empl_pub_all = total(emp*(pubv==1)) , by( country year)
egen empl_pri_all = total(emp*(pubv==0)) , by( country year)



local i =0
foreach var in pri pub{
egen empl_man_`var' = total(emp*(indus==2 & pubv==`i')) , by( country year)
egen empl_serv_`var' = total(emp*(indus==4&pubv==`i')) , by( country year)
local ++i
}


*--> Important industries & sectors:

* Individual became at risk
egen init_indus = max(indus*(age==46)+ indus*(year==1989& age89>46)),by(id)
egen init_pub 	= max((pubv==1&age==46)+ (pubv==1 & year==1989 & age89 > 46)),by(id)
egen init_pri 	= max((pubv==0& unemp_a==0 &age==46)+ (pubv==0 & unemp_a==0 & year==1989& age89>46)),by(id)


* Individual worked before retirement
gen aux = indus if f.t_retire2_a==1
egen last_indus = max(aux), by(id)
egen last_pub 	= max(pubv==1 & f.t_retire2_a ==1), by(id)
egen last_pri 	= max(pubv==0 & f.t_retire2_a ==1), by(id)
drop aux


*--> Separations in the industry/ownership where individual became at risk.


gen risk_2_p = 0 
replace risk_2_p = 1 if (year==1990|year==1991) & age89>=45
replace risk_2_p = 1 if l.age==45 | l2.age==45 & age89<45

local i =0
foreach var1 in pri pub {
local j = 0
foreach var2 in man serv{
local j = `j' +2

local v "`var2'_`var1'"

foreach vs in sep tot_sep nosep risk init{
capture drop `vs'_`v'
}
egen init_`v' = total(empl_`v'*(age==46) + empl_`v'*(year==1989& age89>46)),by(id)
gen sep_`v' = (workv!=l.workv & l.workv!=. & l.indus==`j' & l.pubv==`i' ) 
egen tot_sep_`v' = total(sep_`v'), by(country year)
gen nosep_`v' = tot_sep_`v' ==0

egen risk_`v' = total(tot_sep_`v'*risk_2_p), by(id)
 

}
local ++i
}
 
 
				

capture drop risk_sep_sect2
replace init_man_pri =1 if init_man_pub!=0 & init_man_pri==0
egen risk_sep_sect2 = max(risk_man_pub/init_man_pub*(init_indus== 2 & init_pub==1) + ///
					 risk_man_pri/init_man_pri*(init_indus== 2 & init_pri==1) +  ///
					 risk_serv_pub/init_serv_pub*(init_indus==4 & init_pub==1) +  ///
					 risk_serv_pri/init_serv_pri*(init_indus==4 & init_pri==1)), by(id)
					
 	
 			
*--> Entry in the industry/ownership where individual became at risk.
 
local i =0
foreach var1 in pri pub {
	local j = 0
	foreach var2 in man serv{
		local j = `j' +2
		local v "`var2'_`var1'"

		foreach vs in   entry new cum perc centry {
			capture drop `vs'_`v'
		}


		egen entry_`v' = total(f_school_a*(industry==`j' & pubv==`i')) , by(country year) //same
		gen new_`v' 	= entry_`v'/ empl_`v' //same


		capture drop auxx
		sort country year
		by  country : gen auxx = sum(entry_`v') if fobs==1
		egen cum_`v' 			= min(auxx), by(country year)
		gen  perc_`v' 			= cum_`v' / empl_`v'
		replace  perc_`v'		= 0  if perc_`v' ==.


		sort id year
		egen centry_`v' = max(perc_`v'*(f.t_retire_a==1)), by(id)
		label var centry_`v' "Cumulative entry in `v1' `v2' until retirement"
	}

	local ++i

}
 
egen entry_indus = total(f_school_a), by(indus country year) 
egen entry_man_all = total(f_school_a*(industry==2)), by( country year) 
egen entry_serv_all = total(f_school_a*(industry==4)), by( country year) 

egen entry_pub_all = total(f_school_a*(pubv==1)), by( country year) 
egen entry_pri_all = total(f_school_a*(pubv==0)), by( country year) 
 
foreach var in pub pri man serv{
capture drop auxx
bys  country : gen auxx = sum(entry_`var'_all) if fobs==1
egen aux_`var'_all = min(auxx), by(country year)
egen cum_`var'_all = max(aux_`var'_all*risk_2_p), by(country year)
egen init_`var'_all = total(empl_`var'_all*(age==46) + empl_`var'_all*(year==1989& age89>46)),by(id)

gen in_`var'_all = cum_`var'_all /init_`var'_all

capture drop auxx aux_`var'_all cum_`var'_all 

xtset id year





}



egen tot_entry_all = max(in_man_all*(init_indus== 2) + in_serv_all*(init_indus==4)), by(id)
egen tot_entry_own = max(in_pub_all*(init_pub== 1) + in_pri_all*(init_pri==1)), by(id)

					
egen tot_entry_sect = max(centry_man_pub*(init_indus== 2 & init_pub==1) + ///
					centry_man_pri*(init_indus== 2 & init_pri==1) +  ///
					centry_serv_pub*(init_indus==4 & init_pub==1) +  ///
					centry_serv_pri*(init_indus==4 & init_pri==1)), by(id)

 
 
*-----------------------------------------------------------------------------*				
 foreach own in pri pub{
foreach sect in  serv man{
local so `sect'_`own'

egen aux1 	= mean(risk_`so'), by(year)
egen aux2 	= mean(risk_`so'), by(year c_code)
egen aux3 	= count(risk_`so'), by(year)
egen aux4 	= count(risk_`so'), by(year c_code)

gen risk_plac_`so' = aux1 *aux3 /(aux3 -aux4  ) - aux2 *aux4/(aux3-aux4)


drop aux? 

egen aux1 	= mean(risk_`so')	 
egen aux2 	= mean(risk_`so')	, by(year c_code)		
egen aux3 	= count(risk_`so')	 
egen aux4 	= count(risk_`so')	, by(year c_code)

gen risk_plac2_`so' = aux1 *aux3 /(aux3 -aux4  ) - aux2 *aux4/(aux3-aux4)
drop aux? 
}
}
		
egen empl = sum(emp), by(c_code year)
egen aux1 = sum(workv!= .), by(id)

gen lazy = aux1==0				


drop aux1
gen mkt = industryv ==4
gen man = industryv	==2

xtset id year
quiet{
foreach var in    man pub pri den{
capture drop `var'_gdp

egen tot_`var' = total(`var') , by(c_code year)
gen share_`var' = tot_`var' / empl


gen aux =  `var' if age==45				// Sector when it become at risk 
replace aux=  `var' if age>45 & year==1989

egen `var'_45 = min(aux), by(id)
drop aux


gen aux = share_`var' if f.t_retire2_a==1				// Sector when it dies 
replace aux= share_`var' if year==2006 & retirees ==0 


egen share_`var'_exit = min(aux), by(id)
drop aux  
}

egen max_edu = max(educ), by(id)

gen pre_trans = age89<45 

}
 
egen at_risk =max(age>45), by(id)
gen early_ret =time_event<0	 
